Package: fitbitScraper
Title: Scrapes Data from Fitbit
Version: 0.1.8
Author: Cory Nissen <corynissen@gmail.com> [aut, cre]
Maintainer: Cory Nissen <corynissen@gmail.com>
Description: Scrapes data from Fitbit <http://www.fitbit.com>. This does not use the official
    API, but instead uses the API that the web dashboard uses to generate the graphs
    displayed on the dashboard after login at <http://www.fitbit.com>.
Depends: R (>= 3.0.0)
License: MIT + file LICENSE
LazyData: true
Imports: httr, stringr, jsonlite, methods, utils
URL: https://github.com/corynissen/fitbitScraper
RoxygenNote: 6.0.1
Suggests: knitr, rmarkdown, ggplot2, ggthemes
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2017-04-13 15:19:10 UTC; 60018847
Repository: CRAN
Date/Publication: 2017-04-13 22:12:40 UTC
